/*
   SPDX-FileCopyrightText: 2019-2022 Laurent Montel <montel@kde.org>

   SPDX-License-Identifier: LGPL-2.0-or-later
*/

#pragma once

#include <QObject>

class DMARCInfoTest : public QObject
{
    Q_OBJECT
public:
    explicit DMARCInfoTest(QObject *parent = nullptr);
    ~DMARCInfoTest() override = default;
private Q_SLOTS:
    void shouldHaveDefaultValues();
    void shouldTestExtractDkimKeyRecord_data();
    void shouldTestExtractDkimKeyRecord();
};
